==> spaceway-2.1.0.tar.gz: spaceway-2.1.0/README.md <==
<div align="center">

## Space Way

Arcade game about space, in which you must overcome the space path by flying around obstacles 

![](https://img.shields.io/pypi/v/spaceway) ![](https://img.shields.io/github/release-date/YariKartoshe4ka/Space-Way) ![](https://img.shields.io/pypi/dm/spaceway)

<img src="https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/icons/icon.svg" width=128 />

</div>


### Installation

###### Compiled (Only Windows)

1. Download Space Way installer from [latest releases](https://github.com/YariKartoshe4ka/Space-Way/releases/latest)
2. Launch the installer and install Space Way
3. Launch the program with a shortcut

###### Via pip (All platforms)

1. Install Space Way from PyPI packages
```sh
python -m pip install spaceway
```
2. Run it with shortcut or from terminal
```sh
spaceway
```

### Future

I am not a professional game developer (this is my first game), and I do not know if it makes sense to develop it, but if there is activity on the repository, then I'm going to do:

1. Music and sprites update 
2. Add more obstacles for different levels of difficulty
3. Add support of Android (very far future, >100 stars on this repo)

[and many other things...](https://github.com/YariKartoshe4ka/Space-Way/blob/master/docs/TODO.md)


### Contribution

If you want to contribute to this repo, check out [TODO.md](https://github.com/YariKartoshe4ka/Space-Way/blob/master/docs/TODO.md) and check out what you can do<br>
I am currently looking for artists to evaluate and rework sprites<br>
I welcome information about bugs, ideas and suggestions, always open for issue and pull requests<br>


### Screenshots

|                               |                               |
|-------------------------------|-------------------------------|
|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/lobby.png)|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/jump.png) |
|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/boost.png)|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/end.png)  |

==> spaceway-2.2.0.tar.gz: spaceway-2.2.0/README.md <==
<div align="center">

## Space Way

Arcade game about space, in which you must overcome the space path by flying around obstacles 

![](https://img.shields.io/pypi/v/spaceway) ![](https://img.shields.io/github/release-date/YariKartoshe4ka/Space-Way) ![](https://img.shields.io/pypi/dm/spaceway) <br>
![](https://img.shields.io/codecov/c/github/YariKartoshe4ka/Space-Way) ![](https://img.shields.io/github/issues-raw/YariKartoshe4ka/Space-Way/help%20wanted)

<img src="https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/icons/icon.svg" width=128 />

</div>


### Installation

###### Compiled (Windows 10+)

1. Download Space Way binary from [latest releases](https://github.com/YariKartoshe4ka/Space-Way/releases/latest) (ends on **.exe**)
2. Launch program and play!

###### Compiled (Android 5.0+)

1. Download Space Way package file from [latest releases](https://github.com/YariKartoshe4ka/Space-Way/releases/latest) (ends on **.apk**)
2. Launch it and install Space Way
3. Run game with shortcut and play!

###### Via pip (All platforms)

1. Install Space Way from PyPI packages
```sh
python -m pip install spaceway
```
2. Run it with shortcut or from terminal
```sh
spaceway
```

### Future

I am not a professional game developer (this is my first game), and I do not know if it makes sense to develop it, but if there is activity on the repository, then I'm going to do:

1. Music and sprites update 
2. Add more obstacles for different levels of difficulty

[and many other things...](https://github.com/YariKartoshe4ka/Space-Way/blob/master/docs/TODO.md)


### Contribution

If you want to contribute to this repo, check out [TODO.md](https://github.com/YariKartoshe4ka/Space-Way/blob/master/docs/TODO.md) and check out what you can do<br>
I am currently looking for artists to evaluate and rework sprites<br>
You can also look at the issue marked as *"help wanted"* and help to solve them<br>
I welcome information about bugs, ideas and suggestions, always open for issue and pull requests<br>


### Screenshots

|                               |                               |
|-------------------------------|-------------------------------|
|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/lobby.png)|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/jump.png) |
|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/boost.png)|![](https://raw.githubusercontent.com/YariKartoshe4ka/Space-Way/master/docs/screenshots/end.png)  |
